@@ -66,12 +66,12 @@ def display_alert(args,printer):
     # msg.show ()
     cmd = construct_notification_command(alert_title, alert_message, urgency)
     #    pdb.set_trace()
-    print ("The Command:", str(cmd))
+    printer ("The Command:", str(cmd))
     call(cmd)    
     
 def play_sound(args,printer):
     a = 1
-    #filename = u"~/bin/sounds/" + args[u'sound_file'] + u".ogg"    
+    filename = u"~/bin/sounds/" + args[u'sound_file'] + u".ogg"    
     cmd = [u"play", u"-q", filename]
     printer ("The Command:", str(cmd))
     #call(cmd)
